==> ejc-settlementmanage-impl-3.0.0-20220812.091007-54-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookQuantityBasDeatilVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-收入明细表-工程量依据
 * 
 * @author generator
 * 
 */
public class SettlementBookQuantityBasDeatilVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String listingCode; // 清单编码
    private java.lang.String partProjectName; // 分部分项工程名称
    private java.lang.String units; // 单位
    private java.math.BigDecimal quantities; // 工程量
    private java.lang.String calculationProcess; // 计算过程
    private java.lang.String gist; // 依据
    private java.lang.String source; // 来源
    private java.math.BigDecimal extaxUnitprice; // 合同单价除税
    private java.math.BigDecimal intaxUnitprice; // 合同单价含税

    private java.lang.String errorMsg;
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String innercode;

    private List<SettlementBookQuantityBasDeatilVO> children = new ArrayList<>();

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public List<SettlementBookQuantityBasDeatilVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementBookQuantityBasDeatilVO> children) {
        this.children = children;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 分部分项工程名称
     */
    public java.lang.String getPartProjectName() {
        return partProjectName;
    }

    /**
     * 分部分项工程名称
     */
    public void setPartProjectName(java.lang.String partProjectName) {
        this.partProjectName = partProjectName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }

    public BigDecimal getQuantities() {
        return quantities;
    }

    public void setQuantities(BigDecimal quantities) {
        this.quantities = quantities;
    }

    /**
     * 计算过程
     */
    public java.lang.String getCalculationProcess() {
        return calculationProcess;
    }

    /**
     * 计算过程
     */
    public void setCalculationProcess(java.lang.String calculationProcess) {
        this.calculationProcess = calculationProcess;
    }
    /**
     * 依据
     */
    public java.lang.String getGist() {
        return gist;
    }

    /**
     * 依据
     */
    public void setGist(java.lang.String gist) {
        this.gist = gist;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }

    public BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    public void setExtaxUnitprice(BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }

    public BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    public void setIntaxUnitprice(BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20221022.042622-79-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookQuantityBasDeatilVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-收入明细表-工程量依据
 * 
 * @author generator
 * 
 */
public class SettlementBookQuantityBasDeatilVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String listingCode; // 清单编码
    private java.lang.String partProjectName; // 分部分项工程名称
    private java.lang.String units; // 单位
    private java.math.BigDecimal quantities; // 工程量
    private java.lang.String calculationProcess; // 计算过程
    private java.lang.String gist; // 依据
    private java.lang.String source; // 来源
    private java.math.BigDecimal extaxUnitprice; // 合同单价除税
    private java.math.BigDecimal intaxUnitprice; // 合同单价含税

    private java.lang.String errorMsg;
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String innercode;
    private String section; // 区段
    private String subitemDesc; // 子目特征描述


    private List<SettlementBookQuantityBasDeatilVO> children = new ArrayList<>();

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public List<SettlementBookQuantityBasDeatilVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementBookQuantityBasDeatilVO> children) {
        this.children = children;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 分部分项工程名称
     */
    public java.lang.String getPartProjectName() {
        return partProjectName;
    }

    /**
     * 分部分项工程名称
     */
    public void setPartProjectName(java.lang.String partProjectName) {
        this.partProjectName = partProjectName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }

    public BigDecimal getQuantities() {
        return quantities;
    }

    public void setQuantities(BigDecimal quantities) {
        this.quantities = quantities;
    }

    /**
     * 计算过程
     */
    public java.lang.String getCalculationProcess() {
        return calculationProcess;
    }

    /**
     * 计算过程
     */
    public void setCalculationProcess(java.lang.String calculationProcess) {
        this.calculationProcess = calculationProcess;
    }
    /**
     * 依据
     */
    public java.lang.String getGist() {
        return gist;
    }

    /**
     * 依据
     */
    public void setGist(java.lang.String gist) {
        this.gist = gist;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }

    public BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    public void setExtaxUnitprice(BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }

    public BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    public void setIntaxUnitprice(BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }
}
